@@ -69,7 +69,7 @@ class ArrayType(object):
 class DictType(object):
     def __init__(self, key_type, value_type):
         if key_type not in pod_types:
-            raise ValueError("Dictionnaries key can only be a pod type")
+            raise ValueError("Dictionaries key can only be a pod type")
         self.key_type = key_type
         if iscomplex(value_type):
             self._value_type = weakref.ref(value_type)
@@ -270,7 +270,7 @@ class UuidType(UserType):
     @staticmethod
     def validate(value):
         try:
-            uuid.UUID(value)
+            return six.text_type((uuid.UUID(value)))
         except (TypeError, ValueError, AttributeError):
             error = 'Value should be UUID format'
             raise ValueError(error)
@@ -754,7 +754,7 @@ class BaseMeta(type):
         return type.__new__(cls, name, bases, dct)
 
     def __init__(cls, name, bases, dct):
-        if bases and bases[0] is not object:
+        if bases and bases[0] is not object and cls.__registry__:
             cls.__registry__.register(cls)
 
 
